All environment variables that pavex_cli reads, apart from the ones
defined in the CLI args themselves, are defined here.
The goal: avoid random std::env::var calls all over the place,
and instead have a single place where all environment variables are
defined and documented.
Functions
- The SHA of the commit that
pavex_cliwas built from. - Set a specific
pavexcbinary to be used, regardless of the logic that would otherwise be used to determine it. - This is an undocumented feature that allows us to force set the width of the terminal as seen by the graphical error handler. This is useful for testing/doc-generation purposes.
- The version of
pavex_clithat is being used.