pub fn tty_width() -> Option<usize>
This is an undocumented feature that allows us to force set the width of the terminal as seen by the graphical error handler. This is useful for testing/doc-generation purposes.